@@ -2,10 +2,13 @@
 ## These are not used for any calculations; only used for saving
 ## the network in Hugin format...
 
+## FIXME compile examples to be written
+
 #' @title Compile a graphical independence network (a Bayesian network)
 #' 
 #' @description Compiles a Bayesian network. This means creating a
-#'     junction tree and establishing clique potentials.
+#'     junction tree and establishing clique potentials; ; refer to
+#'     the reference below for details.
 #'
 #' @name grain_compile
 #' 
@@ -22,129 +25,49 @@
 #' @return A compiled Bayesian network; an object of class
 #'     \code{grain}.
 #' @author Søren Højsgaard, \email{sorenh@@math.aau.dk}
+#' 
 #' @seealso \code{\link{grain}}, \code{\link[gRbase]{propagate}},
+#'     \code{\link{propagate.grain}},
 #'     \code{\link[gRbase]{triangulate}}, \code{\link[gRbase]{rip}},
 #'     \code{\link[gRbase]{junctionTree}}
+#'
 #' @references Søren Højsgaard (2012). Graphical Independence
 #'     Networks with the gRain Package for R. Journal of Statistical
 #'     Software, 46(10), 1-26.
 #'     \url{http://www.jstatsoft.org/v46/i10/}.
 #' @keywords utilities models
-#'
-#' @examples
-#' ## To be written
-#' 
-
-
-
-#' @rdname grain_compile
-add_jtree <- function(object, root=NULL){
-    UseMethod("add_jtree")
-}
-
-#' @rdname grain_compile
-add_jtree.cpt_grain <- function(object, root=NULL){
-    if (!inherits(object, "cpt_grain")) stop("Not a cpt_grain object\n") 
-    object[c("rip", "ug")] <- .create_jtree(object, root) 
-    object
-}
-#' @rdname grain_compile
-add_jtree.pot_grain <- function(object, root=NULL){
-    if (is.null(rip(object)))
-        stop("No rip component in object \n")
-    object
-}
-
-
-.create_jtree <- function(object, root=NULL, update=TRUE){
-
-    mdag <- moralize(getgin(object, "dag"), result="dgCMatrix")
-    if (length(root) > 1) mdag <- .setRoot(mdag, root)
-        
-    ug_   <- triangulateMAT(mdag)  ## FIXME : Coercions are a MESS
-    rp_   <- ripMAT( ug_ )
-    ug_   <- as(ug_, "graphNEL")
-
-    list(rip=rp_, ug=ug_)
-}
-
-
-#' @rdname grain_compile
-add_potential <- function(object){
-    UseMethod("add_potential")
-}
-
-#' @rdname grain_compile
-add_potential.cpt_grain <- function(object){
-    object$potential <- .create_potential(object)
-    object
-}
-
-#' @rdname grain_compile
-add_potential.pot_grain <- function(object){
-    if (is.null(object$cqpot))
-        stop("No cqpot component in object \n")
-    object$potential <-
-        list(pot_orig=object$cqpot,
-             pot_temp=object$cqpot,
-             pot_equi=.initArrayList(object$cqpot, NA))
-    ##class(pot_orig) <- class(pot_temp) <- class(pot_equi) <- "pot_spec"
-    object
-}
-
-
-.create_potential <- function(object){
-
-    if (is.null(rip(object)))
-        stop("No rip slot (junction tree) in object\n")
-    if (is.null(cpt(object)))
-        stop("No cpt slot in object\n")
-    
-    pot.1    <- .mkArrayList(rip(object), universe(object))
-    pot_orig <- pot_temp <- .insertCPT(cpt(object), pot.1, details=0)
-    pot_equi <- .initArrayList(pot.1, NA)
-
-    ##class(pot_orig) <- class(pot_temp) <- class(pot_equi) <- "pot_spec"
-    list(pot_orig=pot_orig, pot_temp=pot_temp, pot_equi=pot_equi)
-}
 
 #' @rdname grain_compile
+#' @export
 compile.grain <- function(object, propagate=FALSE, root=NULL,
            control=object$control, details=0, ...) {    
-    NextMethod("compile")
+    
+    object <- .add_jtree(object, root)
+    object <- .add_potential(object)
+    
+    isCompiled(object) <- TRUE
+    isPropagated(object) <- FALSE
+    
+    object$control      <- control
+    
+    if (propagate) propagate(object) else object
 }
 
-
-#' @rdname grain_compile
-compile.cpt_grain <- function(object, propagate=FALSE, root=NULL, control=object$control,
-                              details=0, ...){
-        
-        object <- add_jtree(object, root)
-        object <- add_potential(object)
-        
-        object$isCompiled   <- TRUE
-        object$isPropagated <- FALSE
-        object$control      <- control
-        
-        if (propagate) propagate(object) else object
-    }
+## #' @rdname grain_compile
+## fit.grain <- function(object, propagate=TRUE, root=NULL,
+##            control=object$control, details=0, ...) {    
+##     cl <- match.call(expand.dots = TRUE)
+##     cl[[1]] <- as.name("compile.grain")
+##     eval(cl)
+## }
 
 
-#' @rdname grain_compile
-compile.pot_grain <-
-    function(object, propagate=FALSE, root=NULL, control=object$control,
-             details=0,...) {
-      
-        object <- add_jtree(object, root)
-        object <- add_potential(object)
-        
-        object$isCompiled   <- TRUE
-        object$isPropagated <- FALSE
-        object$control      <- control
-        
-        if (propagate) propagate(object) else object
-    }
 
+## #############################################
+##
+## dot-functions only below here
+##
+## #############################################
 
 .createJTreeGraph <- function(rip){
     if (length(rip$cliques) > 1){
@@ -170,7 +93,6 @@ compile.pot_grain <-
 }
 
 
-
 ## setRoot: Completes the variables in <root> in the graph,
 ## FIXME: setRoot: Assumes sparse matrix. A MESS
 .setRoot <- function(mdagM, root){
@@ -183,17 +105,73 @@ compile.pot_grain <-
     mdagM
 }
 
+.add_jtree <- function(object, root=NULL){
+    UseMethod(".add_jtree")
+}
 
+## #' @rdname grain_compile
+.add_jtree.cpt_grain <- function(object, root=NULL){
+    if (!inherits(object, "cpt_grain")) stop("Not a cpt_grain object\n") 
+    object[c("rip", "ug")] <- .create_jtree(object, root) 
+    object
+}
 
+## #' @rdname grain_compile
+.add_jtree.pot_grain <- function(object, root=NULL){
+    if (is.null(rip(object)))
+        stop("No rip component in object \n")
+    object
+}
 
+.create_jtree <- function(object, root=NULL, update=TRUE){
 
+    mdag <- moralize(getgin(object, "dag"), result="dgCMatrix")
+    if (length(root) > 1) mdag <- .setRoot(mdag, root)
+        
+    ug_   <- triangulateMAT(mdag)  ## FIXME : Coercions are a MESS
+    rp_   <- ripMAT( ug_ )
+    ug_   <- as(ug_, "graphNEL")
 
-    ##gg <- as(getgin(object, "dag"), "dgCMatrix")
-    ##dagList(vpar(getgin(object, "cptlist")), result="dgCMatrix")
-    ##gg <- moralizeMAT(gg)
-    ##mdagM <- moralizeMAT( as(object$dag, "dgCMatrix") )
-    ## Force variables in <root> to be complete in mdagM
-    ## if (length(root) > 1) mdagM <- .setRoot( mdagM, root )
+    list(rip=rp_, ug=ug_)
+}
+
+
+## #' @rdname grain_compile
+.add_potential <- function(object){
+    UseMethod(".add_potential")
+}
+
+## #' @rdname grain_compile
+.add_potential.cpt_grain <- function(object){
+    object$potential <- .create_potential(object)
+    object
+}
+
+## #' @rdname grain_compile
+.add_potential.pot_grain <- function(object){
+    if (is.null(object$cqpot))
+        stop("No cqpot component in object \n")
+
+    object$potential <-
+        list(pot_orig=object$cqpot,
+             pot_temp=object$cqpot,
+             pot_equi=.initArrayList(object$cqpot, NA))
+    object
+}
+
+.create_potential <- function(object){
+
+    if (is.null(rip(object)))
+        stop("No rip slot (junction tree) in object\n")
+    if (is.null(getgrain(object, "cpt")))
+        stop("No cpt slot in object\n")
+    
+    pot.1    <- .mkArrayList(rip(object), universe(object))
+    pot_orig <- pot_temp <- .insertCPT(getgrain(object, "cpt"), pot.1, details=0)
+    pot_equi <- .initArrayList(pot.1, NA)
+
+    list(pot_orig=pot_orig, pot_temp=pot_temp, pot_equi=pot_equi)
+}
 
 
 
